@@ -2,7 +2,7 @@
  * private.h: private DVD reading library data
  *****************************************************************************
  * Copyright (C) 1998-2001 VideoLAN
- * $Id: libdvdcss.h,v 1.2 2002/04/04 14:21:25 sam Exp $
+ * $Id: libdvdcss.h,v 1.5 2002/10/18 18:48:59 sam Exp $
  *
  * Authors: Stphane Borel <stef@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -22,33 +22,44 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
  *****************************************************************************/
 
+struct iovec;
+
 /*****************************************************************************
  * The libdvdcss structure
  *****************************************************************************/
 struct dvdcss_s
 {
     /* File descriptor */
-    int i_fd;
-    int i_seekpos;
+    char * psz_device;
+    int    i_fd;
+    int    i_read_fd;
+    int    i_seekpos;
+
+    /* File handling */
+    int ( * pf_seek )  ( dvdcss_t, int );
+    int ( * pf_read )  ( dvdcss_t, void *, int );
+    int ( * pf_readv ) ( dvdcss_t, struct iovec *, int );
 
     /* Decryption stuff */
     int          i_method;
     css_t        css;
-    boolean_t    b_ioctls;
-    boolean_t    b_encrypted;
+    int          b_ioctls;
+    int          b_scrambled;
     dvd_title_t *p_titles;
 
     /* Error management */
-    char     *psz_error;
-    boolean_t b_errors;
-    boolean_t b_debug;
+    char * psz_error;
+    int    b_errors;
+    int    b_debug;
 
-#if defined( WIN32 )
-    char *p_readv_buffer;
-    int  i_readv_buf_size;
-#else
-    int i_raw_fd;
-    int i_read_fd;
+#ifdef WIN32
+    int    b_file;
+    char * p_readv_buffer;
+    int    i_readv_buf_size;
+#endif
+
+#ifndef WIN32
+    int    i_raw_fd;
 #endif
 };
 
@@ -62,36 +73,6 @@ struct dvdcss_s
 /*****************************************************************************
  * Functions used across the library
  *****************************************************************************/
-int _dvdcss_seek  ( dvdcss_handle, int i_blocks );
-int _dvdcss_read  ( dvdcss_handle, void *p_buffer, int i_blocks );
-
-/*****************************************************************************
- * Error management
- *****************************************************************************/
-#if defined( _WIN32 ) && defined( _MSC_VER )
-#   define DVDCSS_ERROR( x ) fprintf( stderr, "libdvdcss error: %s\n", x );
-#   define DVDCSS_DEBUG( x ) fprintf( stderr, "libdvdcss debug: %s\n", x );
-#else
-#   define DVDCSS_ERROR( x... ) fprintf( stderr, "libdvdcss error: %s\n", ##x );
-#   define DVDCSS_DEBUG( x... ) fprintf( stderr, "libdvdcss debug: %s\n", ##x );
-#endif
-
-static inline void _dvdcss_error( dvdcss_handle dvdcss, char *psz_string )
-{
-    if( dvdcss->b_errors )
-    {
-        DVDCSS_ERROR( psz_string );
-    }
-
-    dvdcss->psz_error = psz_string;
-}
-
-static inline void _dvdcss_debug( dvdcss_handle dvdcss, char *psz_string )
-{
-    if( dvdcss->b_debug )
-    {
-        DVDCSS_DEBUG( psz_string );
-    }
-}
-
+void _dvdcss_error ( dvdcss_t, char * );
+void _dvdcss_debug ( dvdcss_t, char * );
 
